<?php

// PHP functions to create a clickable image with pixel translation data.
//
// Copyright (C) 2006-2011 by Pawel Pilarczyk, http://www.pawelpilarczyk.com/
//
// This file is part of my research software package.  This is free software;
// you can redistribute it and/or modify it under the terms of the GNU Affero
// General Public License as published by the Free Software Foundation,
// either version 3 of the License, or (at your option) any later version.
//
// This software is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public
// License along with this software; see the file "license.txt".
// If not, see <http://www.gnu.org/licenses/>.

// Started in 2006. Last revision: June 27, 2011.


// border width around clickable images;
// warning for a previous version of this PHP file (as of April 2011):
// since different browsers return the position of the clicked pixel
// either with the border included or without the border,
// the border must be set to 0, especially if the tooltip is used
// note: now a wider border can be used (and should be used at least 1)
$border = 1;

// Creates a form with a single clickable image
// and all the necessary data included in hidden fields:
// the height of the picture measured in pixels,
// and the size of each box (which must be square).
// Tooltip values array name: false => no tooltip, true => without array.
function img_click ($pagename, $image, $height, $boxsize, $other,
	$tooltipvalues, $formname)
{
	global $border;

	if ($formname === '')
		$formname = 'main';
	$debug = array_key_exists ("debug", $_REQUEST) ?
		$_REQUEST ["debug"] : 0;
	$test = array_key_exists ("test", $_REQUEST) ?
		$_REQUEST ["test"] : 0;
	$tooltiphtml = ($tooltipvalues !== false) ?
		imgtooltiphtml ($boxsize, $boxsize, $border,
		($tooltipvalues === true) ? false : $tooltipvalues,
		$formname, 0, //$test ? 0 : 1,
		$debug) : "";
	$otherfields = "";
	for ($i = 0; $i < count ($other); ++ $i)
	{
		$name = $other [$i ++];
		$value = $other [$i];
		$otherfields .= "<input\ntype=\"hidden\" " .
			"name=\"${name}\" value=\"${value}\"/>";
	}
	$bordercode = //($border > 0) ?
		"style=\"border:${border}px solid black\"";
	//	: "border=\"0\"";
		

	return <<<IMG
<form name="form_$formname" id="form_$formname"
method="get" action="${pagename}"
enctype="multipart/form-data"><input
type="hidden" name="box_x" value=""/><input
type="hidden" name="box_y" value=""/><input
type="hidden" name="height" value="${height}"/><input
type="hidden" name="boxsize" value="${boxsize}"/>${otherfields}<input
type="image" name="image" src="${image}"
${tooltiphtml}
${bordercode}/></form>
IMG;
	// <!-- style="cursor:crosshair;" -->
} /* img_click */

// Returns a two-element array (x,y) of the coordinates of an image
// from whom the above-defined form redirected.
// It may be requested that Y is measured from the bottom.
// If no coordinates are available then returns the empty array ().
function img_coord ($yFromBottom = false)
{
	global $border;

	// determine box coordinates displayed by the tooltip if available
	$box_x = array_key_exists ("box_x", $_REQUEST) ?
		$_REQUEST ["box_x"] : '';
	$box_y = array_key_exists ("box_y", $_REQUEST) ?
		$_REQUEST ["box_y"] : '';
	if (($box_x !== '') && ($box_y !== ''))
	{
		return array ($box_x, $box_y);
	}

	// determine the coordinates of the point clicked in the image
	$x = array_key_exists ("image_x", $_REQUEST) ?
		$_REQUEST ["image_x"] : '';
	$y = array_key_exists ("image_y", $_REQUEST) ?
		$_REQUEST ["image_y"] : '';

	// get additional information about the image
	$height = array_key_exists ("height", $_REQUEST) ?
		$_REQUEST ["height"] : '';
	$width = array_key_exists ("width", $_REQUEST) ?
		$_REQUEST ["width"] : '';
	$boxsize = array_key_exists ("boxsize", $_REQUEST) ?
		$_REQUEST ["boxsize"] : '';

	// calculate the box that was clicked in the image
	if ((!empty ($x) || ($x === '0')) &&
		(!empty ($y) || ($y === '0')) && !empty ($height) &&
		!empty ($boxsize) && ($boxsize > 0))
	{
		$box_x = intval ($x / $boxsize);
		if ($box_x < 0)
			$box_x = 0;
		$box_y = intval ((($yFromBottom) ? ($height - 1 - $y) : $y) /
			$boxsize);
		if ($box_y < 0)
			$box_y = 0;
		return array ($box_x, $box_y);
	}
	else
	{
		return array ();
	}
}

?>