<?php

// PHP functions which generate beginnings and endings of HTML pages.
//
// Copyright (C) 2006-2011 by Pawel Pilarczyk, http://www.pawelpilarczyk.com/
//
// This file is part of my research software package.  This is free software;
// you can redistribute it and/or modify it under the terms of the GNU Affero
// General Public License as published by the Free Software Foundation,
// either version 3 of the License, or (at your option) any later version.
//
// This software is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public
// License along with this software; see the file "license.txt".
// If not, see <http://www.gnu.org/licenses/>.

// Started in 2006. Last revision: April 18, 2011.


// Set the default timezone, which is now required in PHP.
if (function_exists ('date_default_timezone_set'))
	date_default_timezone_set ("America/New_York");

// Generates HTML code for the beginning of a HTML page.
// $title - the title to be put in the header
// $headcode - additional tags or code to be added to the "head" section
// $bodycode - options to add to the "body" tag
// $indexing - should indexing of the page be allowed for the robots?
function html_begin ($title, $headcode, $bodycode, $indexing)
{
	// prepare a space after the word "body" in the <body> tag
	if (empty ($bodycode))
		$bodyspace = "";
	else
		$bodyspace = " ";

	// prepare a tag to keep indexing robots out
	if ($indexing)
		$norobots = "";
	else
		$norobots = "<meta name=\"robots\" " .
			"content=\"noindex,nofollow,noarchive\">\n";

	// return the HTML code for the beginning of the HTML page
	return <<< HTML
<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8">
<meta name="author" content="Pawel Pilarczyk">
${norobots}<title>${title}</title>
<link rel="stylesheet" media="screen" type="text/css" href="stylescr.css" />
<link rel="stylesheet" media="print" type="text/css" href="styleprt.css" />
${headcode}</head>
<body${bodyspace}${bodycode}>
<div id="text">
HTML;
} /* html_begin */

// Generates HTML code for the end of a HTML page.
function html_end ()
{
	// determine the current year
	if (function_exists ('date_default_timezone_set'))
		date_default_timezone_set ("Europe/Lisbon");
	$curyear = date ('Y');

	// return the code for the end of the HTML page
	return <<< HTML
</div>
<hr/>
<div id="footer"><p>Copyright&nbsp;&copy;&nbsp;2006-${curyear}
by <a href="http://www.pawelpilarczyk.com/">Paweł Pilarczyk</a>.
<br/>The contents of this page is published under the terms
of the <a href="http://www.gnu.org/copyleft/fdl.html">GNU Free
Documentation License</a>.
<br/>The PHP code of this website
is published under the terms of the
<a href="http://www.gnu.org/licenses/agpl.html">GNU Afero
General Public License</a>, and is available
<a href="http://www.pawelpilarczyk.com/database/#files">here</a>.
<br/>All trademarks, registered trademarks or brand names
are property of the respective holders and used in this document
for descriptive purposes only.</p></div>
</body>
</html>
HTML;
} /* html_end */

?>