/////////////////////////////////////////////////////////////////////////////
///
/// @file m_vpol_a.h
///
/// An approximate time-t map for the Vanderpol equations.
/// This map defines a sample time-t map for an ODE.
///
/// @author Pawel Pilarczyk
///
/////////////////////////////////////////////////////////////////////////////

// Copyright (C) 1997-2014 by Pawel Pilarczyk.
//
// This file is part of my research software package. This is free software:
// you can redistribute it and/or modify it under the terms of the GNU
// General Public License as published by the Free Software Foundation,
// either version 3 of the License, or (at your option) any later version.
//
// This software is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this software; see the file "license.txt". If not,
// please, see <https://www.gnu.org/licenses/>.

// Started on December 28, 2010. Last revision: February 11, 2012.


#ifndef _CMGRAPHS_VPOLAPPROX_H_
#define _CMGRAPHS_VPOLAPPROX_H_


// include local header files
#include "maptype.h"
#include "odeapprox.h"


// --------------------------------------------------
// ------------ the Vanderpol time-t map ------------
// --------------------------------------------------

/// An approximate time-t map for the Vanderpol equations.
class MapVanderPolApprox: public MapOdeApprox
{
public:
	/// The constructor of a Vanderpol map object.
	MapVanderPolApprox ();

private:
	/// The vector field.
	void vectorField (double, const double *x, double *y, int dim) const;

}; /* class MapVanderPolApprox */

// --------------------------------------------------

inline MapVanderPolApprox::MapVanderPolApprox ():
	MapOdeApprox (1.0/64, 16, 3)
{
	return;
} /* MapVanderPolApprox::MapVanderPolApprox */

inline void MapVanderPolApprox::vectorField (double,
	const double *x, double *y, int dim) const
{
	if (dim != 2)
		throw "This model is valid in dimension 2 only.";

	// is this the Vanderpol equation with reversed time?
	const bool reversed = false;

	// retrieve the parameters (the left bound only)
	double a = getLeftParam (0);

	// compute the vector field
	y [0] = x [1] - (x [0] * ((x [0] * x [0]) - a));
	y [1] = -x [0];

	// reverse the vector field if requested to
	if (reversed)
	{
		for (int i = 0; i < dim; ++ i)
			y [i] = -y [i];
	}

	return;
} /* MapVanderPolApprox::vectorField */


#endif // _CMGRAPHS_VPOLAPPROX_H_

