/////////////////////////////////////////////////////////////////////////////
///
/// @file procmdec.h
///
/// Dummy post-processing of Morse decompositions.
/// Prepare a customized version of this file every time
/// a different strategy for analysing Morse decompositions
/// is considered right after they have been computed.
///
/// @author Pawel Pilarczyk
///
/////////////////////////////////////////////////////////////////////////////

// Copyright (C) 1997-2014 by Pawel Pilarczyk.
//
// This file is part of my research software package. This is free software:
// you can redistribute it and/or modify it under the terms of the GNU
// General Public License as published by the Free Software Foundation,
// either version 3 of the License, or (at your option) any later version.
//
// This software is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this software; see the file "license.txt". If not,
// please, see <https://www.gnu.org/licenses/>.

// Started on October 8, 2008. Last revision: October 8, 2008.


#ifndef _CMGRAPHS_PROCMDEC_H_
#define _CMGRAPHS_PROCMDEC_H_

// include selected header files from the CHomP library
#include "chomp/system/textfile.h"
#include "chomp/struct/digraph.h"

// include local header files
#include "config.h"
#include "typedefs.h"
#include "conindex.h"
#include "morsedec.h"
#include "typedyns.h"


namespace custom {

/// Dummy version of a function for the post-processing
/// of Morse decompositions.
namespace noProcMorseDec {


// --------------------------------------------------
// ------- post-process a Morse decomposition -------
// --------------------------------------------------

/// Dummy function for post-processing Morse decompositions.
template <class CubSetType, class MorseDecType, class GraphType,
	class CubMapType>
inline void processMorseDec (const MorseDecType &morseDec,
	const CubSetType &X, const GraphType &g,
	const CubMapType &theCubMap0, const CubMapType &theCubMap1,
	const std::string &cubesFilePrefix,
	const std::string &procFilePrefix)
{
	return;
} /* processMorseDec */


} // namespace noProcMorseDec
} // namespace custom


#endif // _CMGRAPHS_PROCMDEC_H_

