#!/usr/bin/perl

#############################################################################
#
# This simple script overcomes the problem with a too long list of arguments
# to the "zip" command while compressing huge sets of files.
# Instead of zipping all the files in the given directory, it splits the list
# to smaller chunks and runs the "zip" command several times to create and
# then to update the archive.
#
#############################################################################

# Copyright (C) 1997-2014 by Pawel Pilarczyk.
#
# This file is part of my research software package. This is free software:
# you can redistribute it and/or modify it under the terms of the GNU
# General Public License as published by the Free Software Foundation,
# either version 3 of the License, or (at your option) any later version.
#
# This software is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this software; see the file "license.txt". If not,
# please, see <https://www.gnu.org/licenses/>.

# Started on April 15, 2008. Last revision: September 15, 2010.

die "Run this script with one or two arguments: archive.zip [prefix].\n"
	if (scalar (@ARGV) < 1);

my $archive = $ARGV[0];
my $prefix = '';
$prefix = $ARGV[1] if (scalar (@ARGV) > 1);

my @files = glob ("${prefix}*");
my $maxlength = 100000;
my $firsttime = (!-f $archive) && (!-f "${archive}.zip");
while (scalar (@files) > 0)
{
	# determine the number of file names which will not exceed the length
	my $count = 0;
	my $length = 40;
	while (($length + length ($files [$count]) < $maxlength) &&
		($count < scalar (@files)))
	{
		$length += length ($files [$count]) + 1;
		++ $count;
	}

	# remove the given number of file names from the list
	my @slice = splice (@files, 0, $count);

	# compress the files
	my $options = ($firsttime) ? "-9 -j" : "-9 -j -u";
	my $cmd = "zip ${options} ${archive} " . join (' ', @slice);
	print "Zipping '${slice[0]}' - '${slice[$#slice]}' " .
		"(${count} files)...\n";
#	print "$cmd\n";
	`$cmd`;
	$firsttime = 0;
}

