/////////////////////////////////////////////////////////////////////////////
///
/// @file typespace.h
///
/// Customizable data types for the Conley-Morse graphs computation program.
/// This file contains the definitions of various types
/// used in the program "cmgraphs.cpp".
/// The experienced end user is supposed to edit this file if he or she
/// finds it necessary to tweak the program settings or to use the code
/// for customized computations.
///
/// @author Pawel Pilarczyk
///
/////////////////////////////////////////////////////////////////////////////

// Copyright (C) 1997-2014 by Pawel Pilarczyk.
//
// This file is part of my research software package. This is free software:
// you can redistribute it and/or modify it under the terms of the GNU
// General Public License as published by the Free Software Foundation,
// either version 3 of the License, or (at your option) any later version.
//
// This software is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this software; see the file "license.txt". If not,
// please, see <https://www.gnu.org/licenses/>.

// Started on February 11, 2008. Last revision: February 20, 2012.


#ifndef _CMGRAPHS_TYPESPACE_H_
#define _CMGRAPHS_TYPESPACE_H_


// include selected header files from the CHomP library
#include "chomp/cubes/pointset.h"
#include "chomp/cubes/cube.h"
#include "chomp/struct/hashsets.h"


// --------------------------------------------------
// ---------- phase space grid structures -----------
// --------------------------------------------------

/// The type of coordinates of cubes in the phase space.
typedef int spcCoord;

/// The type of a cube in the phase space.
/// Note: This type must be different from the type of a cube
/// in the set of parameters.
typedef chomp::homology::tCubeBase<spcCoord> spcCube;

/// The type of a set of cubes in the phase space.
typedef chomp::homology::hashedset<spcCube> spcCubes;

/// The type of a combinatorial cubical multivalued map.
typedef chomp::homology::mvmap<spcCube,spcCube> spcMap;

/// The type of a rectangle used to iterate sets of cubes in the phase space.
typedef chomp::homology::tRectangle<spcCoord> spcRect;


#endif // _CMGRAPHS_TYPESPACE_H_

